@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TDataElement.cc,v 1.1.1.1 2003/06/27 02:56:41 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TDataElement.cc,v 1.3 2003/07/30 16:17:50 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TDataElement.cc,v $
+//  Revision 1.3  2003/07/30 16:17:50  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TDataElement.hh"
 #include "TOutputObjectStream.hh"
@@ -885,30 +890,34 @@ Tint TDataElement::record( TOutputObjectSharedMemory* omemory )
 
 Tostream& operator<<( Tostream& tos, const TDataElement& right )
 {
-  tos << Twspace << Twspace << Twspace << "* Data Element(" << right.theObjectType << "), ";
-  tos << "ID: " << right.theID;
-  tos << Twspace << "Primitives: " << right.theNumberOfPrimitives;
-  tos << Twspace << "Type: " << right.theElementType;
+
+  tos << "Data Element(" << right.theObjectType << "), "
+      << "ID: " << right.theID
+      << ", Type: " << right.theElementType;
 
   switch ( right.theElementType ) {
 
 
     case tTypeInt:
-      tos << Tslash << "Signed integer(" << Tsizeof( Tint ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "Tint(" << Tsizeof( Tint ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tint*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
 
     case tTypeUnsignedInt:
-      tos << Tslash << "Unsigned integer(" << Tsizeof( TUint ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "TUint(" << Tsizeof( TUint ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (TUint*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
@@ -916,76 +925,88 @@ Tostream& operator<<( Tostream& tos, const TDataElement& right )
 
     case tTypeWord:
     case tTypeUnsignedShort:
-      tos << Tslash << "Unsigned short integer(" << Tsizeof( TUshort ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "TUshort(" << Tsizeof( TUshort ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (TUshort*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
 
 
     case tTypeDouble:
-      tos << Tslash << "Double(" << Tsizeof( Tdouble ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "Tdouble(" << Tsizeof( Tdouble ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tdouble*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
 
 
     case tTypeFloat:
-      tos << Tslash << "Float(" << Tsizeof( Tfloat ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "Tfloat(" << Tsizeof( Tfloat ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tfloat*)(right.theData) )[ i ];
 	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	  tos << ", ";
       }
       break;
 
 
 
     case tTypeShort:
-      tos << Tslash << "Signed short integer(" << Tsizeof( Tshort ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "Tshort(" << Tsizeof( Tshort ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tshort*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
 
 
     case tTypeLong:
-      tos << Tslash << "Signed long integer(" << Tsizeof( Tlong ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "Tlong(" << Tsizeof( Tlong ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tlong*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
 
     case tTypeUnsignedLong:
-      tos << Tslash << "Unsigned long integer(" << Tsizeof( TUlong ) << ")" << Twspace << "Data: ";
+      tos << Tslash << "TUlong(" << Tsizeof( TUlong ) << "b), Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (TUlong*)(right.theData) )[ i ];
 	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	  tos << ", ";
       }
       break;
 
 
 
     case tTypeString:
-      tos << Tslash << "String" << Twspace << "Data: ";
+      tos << Tslash << "Tstring, Data("
+          << right.theNumberOfPrimitives << "): ";
       for ( Tint i = 0; i < right.theNumberOfPrimitives; i ++ ) {
 	tos << ( (Tstring*)(right.theData) )[ i ];
-	if ( i != right.theNumberOfPrimitives - 1 )
-	  tos << "," << Tspace;
+	if ( i != right.theNumberOfPrimitives - 1 ) {
+	  tos << ", ";
+        }
       }
       break;
 
@@ -993,8 +1014,7 @@ Tostream& operator<<( Tostream& tos, const TDataElement& right )
     case tTypeUnknown:
     case tTypeObject:
     default:
-      tos << Tslash << "Unknown" << Twspace << "Data: ";
-      tos << "unknown(or undefined) data ...";
+      tos << Tslash << "Unknown, Data: unknown(or undefined) data.";
       break;
   }
 
