@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TDataSection.cc,v 1.1.1.1 2003/06/27 02:56:41 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TDataSection.cc,v 1.3 2003/07/30 16:17:51 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TDataSection.cc,v $
+//  Revision 1.3  2003/07/30 16:17:51  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TDataSection.hh"
 #include "TOutputObjectStream.hh"
@@ -60,20 +65,22 @@ Tint TDataSection::Record( TOutputObjectStream* output )
 
 Tostream& operator<<( Tostream& tos, const TDataSection& right )
 {
-  tos << Twspace + "* Data Section(" << right.theObjectType << "), ";
-  tos << "ID: " << right.theID;
-  tos << Twspace << "Capacity: " << right.capacity();
-  tos << Twspace << "Entry: " << right.size();
+  tos << "Data Section(" << right.theObjectType << "), "
+      << "ID: " << right.theID
+      << ", Capacity: " << right.capacity()
+      << ", Entry: " << right.size();
 
-  if ( right.empty() )
+  if ( right.empty() ) {
     return( tos );
+  }
   
   tos << Tendl;
 
   for ( Tsize_t i = 0; i < right.size(); i ++ ) {
-    tos << right[ i ];
-    if ( i != right.size() - 1 )
+    tos << Ttab << Ttab << "[" << i << "] " << right[ i ];
+    if ( i != right.size() - 1 ) {
       tos << Tendl;
+    }
   }
 
   return( tos );
