@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TDataSegment.cc,v 1.1.1.1 2003/06/27 02:56:41 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TDataSegment.cc,v 1.3 2003/07/30 16:17:51 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TDataSegment.cc,v $
+//  Revision 1.3  2003/07/30 16:17:51  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TDataSegment.hh"
 #include "TOutputObjectStream.hh"
@@ -60,10 +65,10 @@ Tint TDataSegment::Record( TOutputObjectStream* output )
 
 Tostream& operator<<( Tostream& tos, const TDataSegment& right )
 {
-  tos << Twspace + Twspace + "* Data Segment(" << right.theObjectType << "), ";
-  tos << "ID: " << right.theID;
-  tos << Twspace << "Capacity: " << right.capacity();
-  tos << Twspace << "Entry: " << right.size();
+  tos << "Data Segment(" << right.theObjectType << "), "
+      << "ID: " << right.theID
+      << ", Capacity: " << right.capacity()
+      << ", Entry: " << right.size();
 
   if ( right.empty() ) {
     return( tos );
@@ -72,7 +77,7 @@ Tostream& operator<<( Tostream& tos, const TDataSegment& right )
   tos << Tendl;
 
   for ( Tsize_t i = 0; i < right.size(); i ++ ) {
-    tos << right[ i ];
+    tos << Ttab << Ttab << Ttab << "[" << i << "] " << right[ i ];
     if ( i != right.size() - 1 ) {
       tos << Tendl;
     }
