@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TTerminalUserInterface.cc,v 1.2 2003/06/27 21:17:20 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TTerminalUserInterface.cc,v 1.4 2003/07/30 16:18:52 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TTerminalUserInterface.cc,v $
+//  Revision 1.4  2003/07/30 16:18:52  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TTerminalUserInterface.hh"
 #include "TRunManager.hh"
@@ -101,7 +106,6 @@ const Tstring& TTerminalUserInterface::readLine()
 	break;
 
       case _asciiTAB:
-	//DEBUG: under construction
 	completeCommand();
 	break;
 
@@ -153,8 +157,9 @@ const Tstring& TTerminalUserInterface::readLine()
   if ( theAcceptString.size() > 0 ) {
 
     // erase space character form back
-    while ( !( theAcceptString.empty() ) && ( theAcceptString.rfind( Tspace ) == theAcceptString.size() - 1 ) )
+    while ( !( theAcceptString.empty() ) && ( theAcceptString.rfind( Tspace ) == theAcceptString.size() - 1 ) ) {
       theAcceptString.erase( theAcceptString.end() - 1 );
+    }
 
     // erase space character
     while ( !( theAcceptString.empty() ) && ( theAcceptString.find( Tspace ) == 0 ) ) {
@@ -170,14 +175,17 @@ const Tstring& TTerminalUserInterface::readLine()
 
 Tvoid TTerminalUserInterface::insertCharacter( Tchar cc )
 {
-  if ( ! isprint( cc ) )
+  if ( ! isprint( cc ) ) {
     return;
+  }
 
   Tcout << cc;
-  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ )
+  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ ) {
     Tcout << theAcceptString[ i ];
-  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ )
+  }
+  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ ) {
     Tcout << _asciiBS;
+  }
   Tcout << Tflush;
     
   if ( isCursorEnd() ) {
@@ -200,11 +208,13 @@ Tvoid TTerminalUserInterface::backspaceCharacter()
     Tcout << _asciiBS << Tspace << _asciiBS;
   } else {
     Tcout << _asciiBS;
-    for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ )
+    for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ ) {
       Tcout << theAcceptString[ i ];
+    }
     Tcout << Tspace;
-    for ( Tint i = theCursorPosition; i < (Tint)( theAcceptString.size() + 1 ); i ++ )
+    for ( Tint i = theCursorPosition; i < (Tint)( theAcceptString.size() + 1 ); i ++ ) {
       Tcout << _asciiBS;
+    }
   }
   Tcout << Tflush;
   theAcceptString.erase( theCursorPosition - 1, 1 );
@@ -248,12 +258,15 @@ Tvoid TTerminalUserInterface::clearScreen()
 
 Tvoid TTerminalUserInterface::clearAfterCursor()
 {
-  if ( isCursorEnd() )
+  if ( isCursorEnd() ) {
     return;
-  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ )
+  }
+  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ ) {
     Tcout << Tspace;
-  for ( Tint i = (Tint)theAcceptString.size(); i > theCursorPosition; i -- )
+  }
+  for ( Tint i = (Tint)theAcceptString.size(); i > theCursorPosition; i -- ) {
     Tcout << _asciiBS;
+  }
   Tcout << Tflush;
   theAcceptString.erase( theCursorPosition, theAcceptString.size() - theCursorPosition );
   return;
@@ -261,8 +274,9 @@ Tvoid TTerminalUserInterface::clearAfterCursor()
 
 Tvoid TTerminalUserInterface::forwardCursor()
 {
-  if ( isCursorEnd() )
+  if ( isCursorEnd() ) {
     return;
+  }
   Tcout << theAcceptString[ (Tsize_t)( theCursorPosition ) ] << Tflush;
   theCursorPosition ++;
   return;
@@ -270,8 +284,9 @@ Tvoid TTerminalUserInterface::forwardCursor()
 
 Tvoid TTerminalUserInterface::backwardCursor()
 {
-  if ( isCursorTop() )
+  if ( isCursorTop() ) {
     return;
+  }
   Tcout << _asciiBS << Tflush;
   theCursorPosition --;
   return;
@@ -279,70 +294,83 @@ Tvoid TTerminalUserInterface::backwardCursor()
 
 Tvoid TTerminalUserInterface::moveCursorTop()
 {
-  while ( isCursorTop() == Tfalse )
+  while ( isCursorTop() == Tfalse ) {
     backwardCursor();
+  }
   return;
 }
 
 Tvoid TTerminalUserInterface::moveCursorEnd()
 {
-  while ( isCursorEnd() == Tfalse )
+  while ( isCursorEnd() == Tfalse ) {
     forwardCursor();
+  }
   return;
 }
 
 Tvoid TTerminalUserInterface::cutCharacter()
 {
-  if ( !( theStringBuffer.empty() ) )
+  if ( !( theStringBuffer.empty() ) ) {
     theStringBuffer.erase();
-  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ )
+  }
+  for ( Tint i = theCursorPosition; i < (Tint)theAcceptString.size(); i ++ ) {
     theStringBuffer += theAcceptString[ i ];
+  }
   Tint nback = (Tint)( theAcceptString.size() ) - theCursorPosition;
   moveCursorEnd();
-  for ( Tint i = 0; i < nback; i ++ )
+  for ( Tint i = 0; i < nback; i ++ ) {
     backspaceCharacter();
+  }
   return;
 }
 
 Tvoid TTerminalUserInterface::pasteCharacter()
 {
-  if ( theStringBuffer.empty() )
+  if ( theStringBuffer.empty() ) {
     return;
-  for ( int i = 0; i < (Tint)theStringBuffer.size(); i ++ )
+  }
+  for ( int i = 0; i < (Tint)theStringBuffer.size(); i ++ ) {
     insertCharacter( theStringBuffer[ i ] );
+  }
   return;
 }
 
 Tvoid TTerminalUserInterface::nextCommand()
 {
-  if ( theCommandHistoryIndex > (Tint)theCommandHistory.size() - 1 )
+  if ( theCommandHistoryIndex > (Tint)theCommandHistory.size() - 1 ) {
     return;
+  }
   clearLine();
   Tstring com;
-  if ( theCommandHistoryIndex == (Tint)theCommandHistory.size() - 1 )
+  if ( theCommandHistoryIndex == (Tint)theCommandHistory.size() - 1 ) {
     com = theCommandBuffer;
-  else
+  } else {
     com = theCommandHistory[ theCommandHistoryIndex + 1 ];
+  }
 
-  for ( int i = 0; i < (Tint)com.size(); i ++ )
+  for ( int i = 0; i < (Tint)com.size(); i ++ ) {
     insertCharacter( com[ i ] );
+  }
   theCommandHistoryIndex ++;
   return;
 }
 
 Tvoid TTerminalUserInterface::previousCommand()
 {
-  if ( theCommandHistory.empty() || theCommandHistoryIndex == 0 )
+  if ( theCommandHistory.empty() || theCommandHistoryIndex == 0 ) {
     return;
+  }
 
-  if ( theCommandHistoryIndex == (Tint)theCommandHistory.size() )
+  if ( theCommandHistoryIndex == (Tint)theCommandHistory.size() ) {
     theCommandBuffer = theAcceptString;
+  }
 
   clearLine();
 
   Tstring com = theCommandHistory[ theCommandHistoryIndex - 1 ];
-  for ( int i = 0; i < (Tint)com.size(); i ++ )
+  for ( int i = 0; i < (Tint)com.size(); i ++ ) {
     insertCharacter( com[ i ] );
+  }
   theCommandHistoryIndex --;
   return;
 }
@@ -436,14 +464,6 @@ Tvoid TTerminalUserInterface::complete( const Tstring& input )
     Tcout << theAcceptString;
   } else {
 
-
-    // DEBUG ʤ󤫤֤äƤȥϤ㤦
-    // eventview  pureeventview
-    // pureeventview pureeventview-logy
-    // /run ˤ s(TAB)νϷ̤
-    // ccd-daq-1.4.0> s 
-    // s*  s*  start*  stop*  suspend*  shutdown*  status*  setinfo*  showinfo*
-
     for ( Tsize_t i = 0; i < candidate.size(); i ++  ) {
       if ( theCommandTable.GetCommandSpecified( candidate[ i ] ).IsAliasedCommand() ) {
  	local[ i ] += "@";
