@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TUserInterface.cc,v 1.2 2003/06/27 21:17:20 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TUserInterface.cc,v 1.6 2003/07/30 16:18:52 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TUserInterface.cc,v $
+//  Revision 1.6  2003/07/30 16:18:52  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TUserInterface.hh"
 #include "TCommand.hh"
@@ -10,16 +15,43 @@ static Tchar* _clear = "clear";
 static Tchar* _cols = "cols";
 static Tchar* _lines = "lines";
 
+
 TUserInterface::TUserInterface( const Tstring& history )
   : theCommandTable(),
     theHistoryFileStream(),
     theCurrentWorkingDirectory( Tslash ), 
     theCommandHistory()
 {
-  theHistoryFileStream.open( history.c_str(), Tout );
-  if ( !( theHistoryFileStream.good() ) ) {
-    Tcerr << "TUserInterface::TUserInterface: fail to open a file ";
-    Tcerr << history << "." << Tendl;
+  if ( isexist( history ) ) {
+    // Ʊ̾Υե뤬Хڥɥ⡼ɤ,Υեҥȥɲ
+    theHistoryFileStream.open( history.c_str(), Tout|Tapp );
+    if ( !( theHistoryFileStream.good() ) ) {
+      Tcerr << "TUserInterface::TUserInterface: fail to open a file ";
+      Tcerr << history << "." << Tendl;
+    }
+
+    // ҥȥɲ
+    Tifstream ifs( history.c_str() );
+    static const Tsize_t buflen = 1024;
+    static Tchar buf[ buflen ];
+    Tstring strbuf;
+    while ( ifs.getline( buf, buflen ) && !ifs.eof() ) {
+      if ( ifs.fail() || !ifs.good() ) {
+        break;
+      }
+      strbuf = buf;
+      if ( !strbuf.empty() ) {
+        theCommandHistory.push_back( strbuf );
+      }
+    }
+    ifs.close();
+
+  } else {
+    theHistoryFileStream.open( history.c_str(), Tout );
+    if ( !( theHistoryFileStream.good() ) ) {
+      Tcerr << "TUserInterface::TUserInterface: fail to open a file ";
+      Tcerr << history << "." << Tendl;
+    }
   }
 
   theCommandTable.Clear();
