@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TSoftwareDataFileModule.cc,v 1.1.1.1 2003/06/27 02:56:41 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TSoftwareDataFileModule.cc,v 1.3 2003/07/30 16:19:11 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TSoftwareDataFileModule.cc,v $
+//  Revision 1.3  2003/07/30 16:19:11  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TSoftwareDataFileModule.hh"
 #include "TDataSegment.hh"
@@ -105,8 +110,9 @@ TSoftwareDataFileModule::~TSoftwareDataFileModule()
 
 Tint TSoftwareDataFileModule::Clear()
 {
-  for ( Tint i = 0; i < theNumberOfChannels; i ++ )
+  for ( Tint i = 0; i < theNumberOfChannels; i ++ ) {
     theChannel[ i ] = 0.0;
+  }
   return( theStatus = tStatusSuccess );
 }
 
@@ -209,15 +215,18 @@ const Tstring& TSoftwareDataFileModule::eraseComment( Tstring& readline ) const
   for ( Tsize_t i = 0; i < theCommentStringList.size(); i ++ ) {
     Tsize_t pos = readline.find( theCommentStringList[ i ] );
     Tsize_t bufsize = readline.size();
-    if ( pos >= 0 && pos <= bufsize - theCommentStringList[ i ].size() )
+    if ( pos >= 0 && pos <= bufsize - theCommentStringList[ i ].size() ) {
       readline.erase( pos, bufsize - pos );
+    }
   }
 
-  while ( !( readline.empty() ) && readline.rfind( Tspace ) == readline.size() - 1 )
+  while ( !( readline.empty() ) && readline.rfind( Tspace ) == readline.size() - 1 ) {
     readline.erase( readline.end() - 1 );
+  }
 
-  while ( !( readline.empty() ) && readline.find( Tspace ) == 0 )
+  while ( !( readline.empty() ) && readline.find( Tspace ) == 0 ) {
     readline.erase( readline.begin() );
+  }
 
   return( readline );
 }
@@ -235,8 +244,9 @@ TdoubleList TSoftwareDataFileModule::divideLine( Tstring readline ) const
     do {
       begin = readline.find_first_not_of( theSeparater, end );
       end = readline.find( theSeparater, begin );
-      if ( end > readline.size() )
+      if ( end > readline.size() ) {
 	end = readline.size();
+      }
       strbuf = readline.substr( begin, end - begin );
       dbllist.push_back( atof( strbuf.c_str() ) );
     } while ( begin != lastpos );
@@ -249,8 +259,9 @@ TdoubleList TSoftwareDataFileModule::divideLine( Tstring readline ) const
   } else if ( dbllist.size() < (Tsize_t)theNumberOfChannels ) {
     Tcerr << head << "less than required channels." << Tendl;
     Tcerr << head << "filled 0.0." << Tendl;
-    for ( Tsize_t i = 0; i < theNumberOfChannels - dbllist.size(); i ++ )
+    for ( Tsize_t i = 0; i < theNumberOfChannels - dbllist.size(); i ++ ) {
       dbllist.push_back( 0.0 );
+    }
   }
 
   return( dbllist );
@@ -278,11 +289,13 @@ Tint TSoftwareDataFileModule::getNumberOfLine() const
       }
       tifs.getline( linebuf, theBufferLength );
       strbuf = linebuf;
-    if ( !( strbuf.empty() ) )  // for empty line
-      eraseComment( strbuf );
+      if ( !( strbuf.empty() ) ) { // for empty line
+        eraseComment( strbuf );
+      }
     } while ( strbuf.empty() );
-    if ( !( tifs.eof() ) )
+    if ( !( tifs.eof() ) ) {
       nline ++;
+    }
   }
   delete [] linebuf;
   tifs.close();
