@@ -1,6 +1,14 @@
 // =====================================================================
-//  $Id: TRunManager.cc,v 1.2 2003/06/27 10:00:36 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TRunManager.cc,v 1.5 2003/07/30 18:16:36 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TRunManager.cc,v $
+//  Revision 1.5  2003/07/30 18:16:36  goiwai
+//  /run/setid ޥɤɲäޤ.
+//
+//  Revision 1.4  2003/07/30 16:20:31  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TRunManager.hh"
 #include "TEventManager.hh"
@@ -31,6 +39,7 @@
 #include "TRunResumeCommand.hh"
 #include "TRunShutdownCommand.hh"
 #include "TShowRunManagerCommand.hh"
+#include "TSetRunIdCommand.hh"
 #include "TAnalysisStartCommand.hh"
 #include "TAnalysisStopCommand.hh"
 #include "TAnalysisSuspendCommand.hh"
@@ -168,19 +177,14 @@ Tvoid TRunManager::SessionStart()
     }
 
 
-    /////////////////////////////////////////////////
-    // add history
+    // Ϥҥȥ¸
     TCommandHistory& commandhistory = theUserInterface -> GetCommandHistory();
-    Tofstream& tofs = theUserInterface -> GetHistoryFileStream();
-
-    tofs << Twslash << Tspace;
-    tofs << commandhistory.size() << Ttab;
-    tofs << theRunClock.WhatTimeIsItNow() << Tendl;
-    tofs << input << Tendl;
+    Tofstream& of = theUserInterface -> GetHistoryFileStream();
+    of << input << Tendl;
     commandhistory.push_back( input );
-    /////////////////////////////////////////////////
 
 
+    // Ϥβ
     TstringList args = divide( input );
     Tstring comname = args[ 0 ];
     args.erase( args.begin() );
@@ -604,8 +608,8 @@ Tvoid TRunManager::PrintAuthorInformation( Tostream& tos ) const
   tos << Tendl;
   tos << "Project: " << Tproject << Tendl;
   tos << "Version: " << Tversion << Tendl;
-  tos << "$Id: TRunManager.cc,v 1.2 2003/06/27 10:00:36 goiwai Exp $" << Tendl;
-  tos << "$Name: CLDAQ-1-06-02 $" << Tendl;
+  tos << "$Id: TRunManager.cc,v 1.5 2003/07/30 18:16:36 goiwai Exp $" << Tendl;
+  tos << "$Name: CLDAQ-1-07-00 $" << Tendl;
   for ( Tint col = 0; col < ncol; col ++ ) {
     tos << "-";
   }
@@ -867,6 +871,7 @@ Tvoid TRunManager::installDefaultCommand()
   SetUserCommand( new TShowRunManagerCommand( this ) );
   SetUserCommand( new TRunTimeLimitCommand( this ) );
   SetUserCommand( new TRunEventLimitCommand( this ) );
+  SetUserCommand( new TSetRunIdCommand( this ) );
   return;
 }
 
