@@ -1,6 +1,11 @@
 // =====================================================================
-//  $Id: TMacroFileParser.cc,v 1.1.1.1 2003/06/27 02:56:42 goiwai Exp $
-//  $Name: CLDAQ-1-06-02 $
+//  $Id: TMacroFileParser.cc,v 1.4 2003/07/30 16:21:21 goiwai Exp $
+//  $Name: CLDAQ-1-07-00 $
+//
+//  $Log: TMacroFileParser.cc,v $
+//  Revision 1.4  2003/07/30 16:21:21  goiwai
+//  ե˥ߥåȥĤ뤳Ȥˤޤ.
+//
 // =====================================================================
 #include "TMacroFileParser.hh"
 
@@ -61,65 +66,79 @@ Tvoid TMacroFileParser::Open( const Tstring& filename )
 
 Tbool TMacroFileParser::IsOpen()
 {
-  if ( theMacroFileStream.is_open() == Ttrue )
+  if ( theMacroFileStream.is_open() == Ttrue ) {
     return( Ttrue );
-  return( Tfalse );
+  } else {
+    return( Tfalse );
+  }
 }
 
 Tbool TMacroFileParser::IsFail() const
 {
-  if ( theMacroFileStream.fail() == Ttrue )
+  if ( theMacroFileStream.fail() == Ttrue ) {
     return( Ttrue );
-  return( Tfalse );
+  } else {
+    return( Tfalse );
+  }
 }
 
 Tbool TMacroFileParser::IsGood() const
 {
-  if ( theMacroFileStream.good() == Ttrue )
+  if ( theMacroFileStream.good() == Ttrue ) {
     return( Ttrue );
-  return( Tfalse );
+  } else {
+    return( Tfalse );
+  }
 }
 
 Tbool TMacroFileParser::IsEndOfFile() const
 {
-  if ( theMacroFileStream.eof() == Ttrue )
+  if ( theMacroFileStream.eof() == Ttrue ) {
     return( Ttrue );
-  return( Tfalse );
+  } else {
+    return( Tfalse );
+  }
 }
 
 Tbool TMacroFileParser::IsSuccess()
 {
-  if ( IsOpen() && !IsFail() && !IsEndOfFile() )
+  if ( IsOpen() && !IsFail() && !IsEndOfFile() ) {
     return( Ttrue );
-  return( Tfalse );
+  } else {
+    return( Tfalse );
+  }
 }
 
 Tbool TMacroFileParser::IsExecutable( const TstringList& readbuf ) const
 {
-  if ( readbuf.empty() )
+  if ( readbuf.empty() ) {
     return( Tfalse );
-  return( Ttrue );
+  } else {
+    return( Ttrue );
+  }
 }
 
 Tvoid TMacroFileParser::Close()
 {
-  if ( IsOpen() )
+  if ( IsOpen() ) {
     theMacroFileStream.close();
+  }
   return;
 }
 
 TstringList TMacroFileParser::ReadLine()
 {
   static const Tsize_t bufflen = 1024;
+  static Tchar linebuf[ bufflen ];
+
   TstringList listbuf;
   listbuf.clear();
   Tstring strbuf;
-  Tchar* linebuf = new Tchar[ bufflen ];
   theMacroFileStream.getline( linebuf, bufflen );
   strbuf = linebuf;
-  if ( !( strbuf.empty() ) )
+  if ( !( strbuf.empty() ) ) {
     eraseComment( strbuf );
-  delete [] linebuf;
+  }
   listbuf = divideLine( strbuf );
 
   return( listbuf );
@@ -128,8 +147,9 @@ TstringList TMacroFileParser::ReadLine()
 Tstring TMacroFileParser::GetCommand( const TstringList& readbuf ) const
 {
   Tstring command;
-  if ( !readbuf.empty() )
+  if ( !readbuf.empty() ) {
     command = readbuf[ 0 ];
+  }
   return( command );
 }
 
@@ -137,10 +157,11 @@ TstringList TMacroFileParser::GetArguments( const TstringList& readbuf ) const
 {
   TstringList arguments = readbuf;
 
-  if ( arguments.size() > 0 )
+  if ( arguments.size() > 0 ) {
     arguments.erase( arguments.begin() );
-  else
+  } else {
     arguments.clear();
+  }
 
   return( arguments );
 }
@@ -159,15 +180,18 @@ const Tstring& TMacroFileParser::eraseComment( Tstring& readline ) const
   for ( Tsize_t i = 0; i < theCommentStringList.size(); i ++ ) {
     Tsize_t pos = readline.find( theCommentStringList[ i ] );
     Tsize_t bufsize = readline.size();
-    if ( pos >= 0 && pos <= bufsize - theCommentStringList[ i ].size() )
+    if ( pos >= 0 && pos <= bufsize - theCommentStringList[ i ].size() ) {
       readline.erase( pos, bufsize - pos );
+    }
   }
 
-  while ( !( readline.empty() ) && readline.rfind( Tspace ) == readline.size() - 1 )
+  while ( !( readline.empty() ) && readline.rfind( Tspace ) == readline.size() - 1 ) {
     readline.erase( readline.end() - 1 );
+  }
 
-  while ( !( readline.empty() ) && readline.find( Tspace ) == 0 )
+  while ( !( readline.empty() ) && readline.find( Tspace ) == 0 ) {
     readline.erase( readline.begin() );
+  }
 
   return( readline );
 }
@@ -185,13 +209,13 @@ TstringList TMacroFileParser::divideLine( Tstring& readline ) const
     do {
       begin = readline.find_first_not_of( Tspace, end );
       end = readline.find( Tspace, begin );
-      if ( end > readline.size() )
+      if ( end > readline.size() ) {
 	end = readline.size();
+      }
       strbuf = readline.substr( begin, end - begin );
       listbuf.push_back( strbuf );
     } while ( begin != lastpos );
   }
 
-
   return( listbuf );
 }
